@@ -1,7 +1,7 @@
 package Bread::Board::Literal;
 use Moose;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Bread::Board::Service';
@@ -12,13 +12,11 @@ has 'value' => (
     required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-
-no Moose;
-
 sub get { (shift)->value }
 
-1;
+__PACKAGE__->meta->make_immutable;
+
+no Moose; 1;
 
 __END__
 
@@ -52,7 +50,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
