@@ -1,15 +1,15 @@
 package Bread::Board::Service;
 use Moose::Role;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'MooseX::Param',
      'Bread::Board::Traversable';
 
 has 'name' => (
-    is       => 'rw', 
-    isa      => 'Str', 
+    is       => 'rw',
+    isa      => 'Str',
     required => 1
 );
 
@@ -20,26 +20,24 @@ has 'is_locked' => (
 );
 
 has 'lifecycle' => (
-    is      => 'rw', 
-    isa     => 'Str', 
+    is      => 'rw',
+    isa     => 'Str',
     trigger => sub {
         my ($self, $lifecycle) = @_;
         if ($self->does('Bread::Board::LifeCycle')) {
             bless $self => ($self->meta->superclasses)[0];
             return if $lifecycle eq 'Null';
         }
-        ("Bread::Board::LifeCycle::${lifecycle}")->meta->apply($self);        
+        ("Bread::Board::LifeCycle::${lifecycle}")->meta->apply($self);
     }
 );
 
 requires 'get';
 
-no Moose::Role;
-
 sub lock   { (shift)->is_locked(1) }
 sub unlock { (shift)->is_locked(0) }
 
-1;
+no Moose::Role; 1;
 
 __END__
 
@@ -81,7 +79,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
