@@ -1,19 +1,17 @@
 package Bread::Board::Traversable;
 use Moose::Role;
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.08';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'parent' => (
-    is          => 'rw',
-    isa         => 'Bread::Board::Traversable',
-    is_weak_ref => 1,
-    clearer     => 'detach_from_parent',
-    predicate   => 'has_parent',
+    is        => 'rw',
+    isa       => 'Bread::Board::Traversable',
+    weak_ref  => 1,
+    clearer   => 'detach_from_parent',
+    predicate => 'has_parent',
 );
 
-no Moose::Role;
-
 sub get_root_container {
     my $c = shift;
     while ($c->has_parent) {
@@ -36,7 +34,7 @@ sub fetch {
         } while (defined $path[0] && $path[0] eq '..' && $c->has_parent);
         $root = $c;
     }
-    
+
     return $root unless @path;
 
     my $c = $root;
@@ -48,33 +46,33 @@ sub fetch {
 
 sub _get_container_or_service {
     my ($c, $name) = @_;
-    
+
     if ($c->isa('Bread::Board::Dependency')) {
         # make sure to evaluate this from the parent
         return _get_container_or_service($c->parent->parent, $name);
-    }        
-    
+    }
+
     if ($c->does('Bread::Board::Service::WithDependencies')) {
         return $c->get_dependency($name) if $c->has_dependency($name);
         confess "Could not find dependency ($name) from service " . $c->name;
     }
-    
+
     # name() is implemented in Service and Container
     # get_sub_container and get_service is implemented in Container
     # there must be a better way to do this
-    
+
     if ($c->does('Bread::Board::Service')) {
         return $c                           if $c->name eq $name;
     } elsif ($c->isa('Bread::Board::Container')) {
         return $c                           if $c->name eq $name;
         return $c->get_sub_container($name) if $c->has_sub_container($name);
         return $c->get_service($name)       if $c->has_service($name);
-    }        
-    
+    }
+
     confess "Could not find container or service for $name";
 }
 
-1;
+no Moose::Role; 1;
 
 __END__
 
@@ -116,7 +114,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+Copyright 2007-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
